Index: include/gpu/GrGpuResource.h |
diff --git a/include/gpu/GrGpuResource.h b/include/gpu/GrGpuResource.h |
index 3c87117124d66d98178867ee6af7828d328c410f..5231b15f897cd86278443c257ee7b6ae0e90bb86 100644 |
--- a/include/gpu/GrGpuResource.h |
+++ b/include/gpu/GrGpuResource.h |
@@ -16,6 +16,7 @@ |
class GrContext; |
class GrGpu; |
class GrResourceCache2; |
+class GrResourceCacheEntry; |
/** |
* Base class for GrGpuResource. Handles the various types of refs we need. Separated out as a base |
@@ -125,7 +126,7 @@ |
}; |
/** |
* Base class for objects that can be kept in the GrResourceCache2. |
*/ |
class SK_API GrGpuResource : public GrIORef<GrGpuResource> { |
public: |
@@ -256,6 +257,7 @@ |
uint32_t fFlags; |
+ GrResourceCacheEntry* fCacheEntry; // NULL if not in cache |
mutable size_t fGpuMemorySize; |
const uint32_t fUniqueID; |
@@ -125,7 +126,7 @@ |
}; |
/** |
- * Base class for objects that can be kept in the GrResourceCache2. |
+ * Base class for objects that can be kept in the GrResourceCache. |
*/ |
class SK_API GrGpuResource : public GrIORef<GrGpuResource> { |